@@ -17,7 +17,7 @@
 from tempest.services.volume.json.admin import volume_types_client
 
 
-class VolumeTypesV2ClientJSON(volume_types_client.BaseVolumeTypesClientJSON):
+class VolumeTypesV2Client(volume_types_client.BaseVolumeTypesClient):
     """
     Client class to send CRUD Volume V2 API requests to a Cinder endpoint
     """
