@@ -16,7 +16,7 @@
 from tempest.services.volume.json import backups_client
 
 
-class BackupsClientV2JSON(backups_client.BaseBackupsClientJSON):
+class BackupsClientV2(backups_client.BaseBackupsClient):
     """
     Client class to send CRUD Volume V2 API requests to a Cinder endpoint
     """
